from enum import Enum


class OperationTypeEnum(Enum):
    add = 'add'
    update = 'update'
    disable = 'disable'
    stopSell = 'stopSell'
    startSell = 'startSell'


class HistoryOrderUpdateEnum(Enum):
    history = 'history'


class CategoryEnum(Enum):

    credit = 'credit'  # 信用账户
    shares = 'shares'  # 股票账户

# 中信委托类型
class TradeSide(Enum):

    BUY = '1'
    MARGIN_BUY = 'A'
    DEBIT_BUY = 'C'
    SELL = '2'
    MARGIN_SELL = 'B'
    DEBIT_SELL = 'D'

# 中金委托类型
# class TradeSide(Enum):
#
#     BUY = '23'
#     MARGIN_BUY = '27'
#     DEBIT_BUY = '29'
#     SELL = '24'
#     MARGIN_SELL = '28'
#     DEBIT_SELL = '31'

# 中信报价类型
class PriceType(Enum):
    STOCK_LIMIT = '0'

# 中金报价类型
# class PriceType(Enum):
#     STOCK_LIMIT = '11'

if __name__ == '__main__':
    side = TradeSide('1')
    print(side)
    side2 = TradeSide['BUY']
    print(side2)



import time
from configparser import ConfigParser

import pika
from kindenty.base import log
from pika.exchange_type import ExchangeType


class RabbitMq:
    def __init__(self):
        self.connection = None
        self.queue = None
        self.channel = None
        configParser = ConfigParser()
        configParser.read('conf/config.ini', encoding='utf-8')
        host = configParser.get('rabbitmq', 'host')
        user = configParser.get('rabbitmq', 'userName')
        password = configParser.get('rabbitmq', 'password')
        virtualHost = configParser.get('rabbitmq', 'virtualHost')
        self.queueName = configParser.get('rabbitmq', 'queueName')
        self.routingKey = configParser.get('rabbitmq', 'routingKey')
        self.exchange = 'strategy.topic.exchange'
        userX = pika.PlainCredentials(user, password)
        self.parameters = pika.ConnectionParameters(host=host, virtual_host=virtualHost, credentials=userX)
        self.connect()

    def bindConsumer(self, fun):
        def callback(ch, method, prop, body):
            log.debug('method:%s,prop:%s,body:%s' % (method, prop, body))
            fun(method.routing_key, body)
            # self.channel.basic_ack(delivery_tag=method.delivery_tag)
        self.channel.basic_consume(queue=self.queueName, on_message_callback=callback, auto_ack=True)
        while True:
            try:
                self.channel.start_consuming()
            except Exception as e:
                log.error('rabbitmq consumer error', exc_info=e)
                if not self.connection or self.channel.is_closed:
                    self.connect()
                    self.channel.basic_consume(queue=self.queueName, on_message_callback=callback, auto_ack=True)
                time.sleep(1)

    def sendMsg(self, routingKey, body):
        self.channel.basic_publish(self.exchange, routing_key=routingKey, body=body)

    def close(self):
        self.connection.close()

    def connect(self):
        self.connection = pika.BlockingConnection(self.parameters)
        self.channel = self.connection.channel()
        self.channel.exchange_declare(exchange=self.exchange, exchange_type=ExchangeType.topic,
                                      durable=True)
        self.queue = self.channel.queue_declare(self.queueName, durable=True)
        keys = self.routingKey.split(',')
        for key in keys:
            self.channel.queue_bind(queue=self.queueName, exchange=self.exchange, routing_key=key)
